Index: simple_gmap/simple_gmap.module
===================================================================
--- simple_gmap/simple_gmap.module	(revision 98)
+++ simple_gmap/simple_gmap.module	(revision 111)
@@ -22,6 +22,7 @@
     'field types' => array('text'),
     'settings' => array(
       'include_map' => 1,
+      'include_static_map' => 0,
       'include_link' => 0,
       'include_text' => 0,
       'iframe_height' => 200,
@@ -45,6 +46,7 @@
     'simple_gmap_output' => array(
       'variables' => array(
         'include_map' => TRUE,
+        'include_static_map' => FALSE,
         'include_link' => FALSE,
         'include_text' => FALSE,
         'width' => 200,
@@ -56,6 +58,7 @@
         'address_text' => '',
         'map_type' => 'm',
         'langcode' => 'en',
+        'static_map_type' => 'roadmap',
       ),
       'template' => 'simple-gmap-output',
     ),
@@ -75,11 +78,12 @@
 
   // Figure out what to display for each item we have here.
   $embed = (int) $display['settings']['include_map'] ? TRUE : FALSE;
+  $static = (isset($display['settings']['include_static_map']) && (int) $display['settings']['include_static_map'] ) ? TRUE : FALSE;
   $link = (int) $display['settings']['include_link'] ? TRUE : FALSE;
   $text = (int) $display['settings']['include_text'] ? TRUE : FALSE;
 
-  $height = $embed ? (int) $display['settings']['iframe_height'] : 1;
-  $width = $embed ? (int) $display['settings']['iframe_width'] : 1;
+  $height = (int) $display['settings']['iframe_height'];
+  $width = (int) $display['settings']['iframe_width'];
   $link_text = $link ? check_plain($display['settings']['link_text']) : '';
   $bubble = $display['settings']['information_bubble'] ? TRUE : FALSE;
   $zoom_level = (int) $display['settings']['zoom_level'];
@@ -99,12 +103,15 @@
     $map_type = 'm';
   }
 
+  // For some reason, static gmaps accepts a different value for map type.
+  $static_map_types = array('m' => 'roadmap', 'k' => 'satellite', 'h' => 'hybrid', 'p' => 'terrain');
   foreach($items as $delta => $item) {
     $url_value = urlencode(check_plain($item['value']));
     $address = $text ? check_plain($item['value']) : '';
 
     $element[$delta] = array('#markup' => theme('simple_gmap_output', array(
           'include_map' => $embed,
+          'include_static_map' => $static,
           'include_link' => $link,
           'include_text' => $text,
           'width' => $width,
@@ -116,6 +123,7 @@
           'address_text' => $address,
           'map_type' => $map_type,
           'langcode' => $lang_to_use,
+          'static_map_type' => $static_map_types[$map_type],
         )));
   }
 
@@ -137,10 +145,16 @@
 
   $element['include_map'] = array(
     '#type' => 'checkbox',
-    '#title' => t('Include embedded map'),
+    '#title' => t('Include embedded dynamic map'),
     '#default_value' => (int) $settings['include_map'],
   );
 
+  $element['include_static_map'] = array(
+    '#type' => 'checkbox',
+    '#title' => t('Include embedded static map'),
+    '#default_value' => (isset($settings['include_static_map'])) ? (int) $settings['include_static_map'] : 0,
+  );
+
   $element['iframe_width'] = array(
     '#title' => t('Width of embedded map'),
     '#type' => 'textfield',
@@ -246,6 +260,9 @@
 function simple_gmap_field_formatter_settings_summary($field, $instance, $view_mode) {
   $display = $instance['display'][$view_mode];
   $settings = $display['settings'];
+  if (!isset($settings['include_static_map'])) {
+    $settings['include_static_map'] = 0;
+  }
 
   $information_bubble = $settings['information_bubble'] ? t('Yes') : t('No');
 
@@ -263,11 +280,14 @@
   if ($settings['include_map']) {
     $summary[] = t('Embedded map: @width x @height', array('@width' => $settings['iframe_width'], '@height' => $settings['iframe_height']));
   }
+  if ($settings['include_static_map']) {
+    $summary[] = t('Static map: @width x @height', array('@width' => $settings['iframe_width'], '@height' => $settings['iframe_height']));
+  }
   if ($settings['include_link']) {
     $summary[] = t('Map link: @link_text', array('@link_text' => $settings['link_text']));
   }
 
-  if ($settings['include_map'] || $settings['include_link']) {
+  if ($settings['include_map'] || $settings['include_static_map'] || $settings['include_link']) {
     $language = isset($display['settings']['langcode']) ? check_plain($display['settings']['langcode']) : 'en';
     $summary[] = t('Map Type: @map_type', array('@map_type' => $map_type));
     $summary[] = t('Zoom Level: @zoom_level', array('@zoom_level' => $settings['zoom_level']));
Index: simple_gmap/simple-gmap-output.tpl.php
===================================================================
--- simple_gmap/simple-gmap-output.tpl.php	(revision 98)
+++ simple_gmap/simple-gmap-output.tpl.php	(revision 111)
@@ -4,7 +4,8 @@
  * Displays the Simple Google Maps formatter.
  *
  * Available variables:
  * - $include_map: TRUE if an embedded map should be displayed.
  * - $width: Width of embedded map.
  * - $height: Height of embedded map.
  * - $include_link: TRUE if a link to a map should be displayed.
@@ -19,6 +20,8 @@
  *   displayed).
  * - $map_type: Type of map to use (Google code, such as 'm' or 't').
  * - $langcode: Two-letter language code to use.
+ * - $static_map_type: Type of map to use for static map (Google code, such as
+ *  'roadmap' or 'satellite')
  *
  * @ingroup themeable
  */
@@ -27,6 +30,13 @@
 <iframe width="<?php print $width; ?>" height="<?php print $height; ?>" frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="http://maps.google.com/maps?hl=<?php print $langcode; ?>&amp;q=<?php print $url_suffix; ?>&amp;iwloc=<?php print ($information_bubble ? 'A': ''); ?>&amp;z=<?php print $zoom; ?>&amp;t=<?php print $map_type; ?>&amp;output=embed"></iframe>
 <?php
 }
+if ($include_static_map) {
+?>
+<div class="simple-gmap-static-map">
+  <img src="http://maps.googleapis.com/maps/api/staticmap?size=<?php print $width; ?>x<?php print $height; ?>&amp;zoom=<?php print $zoom; ?>&amp;language=<?php print $langcode; ?>&amp;maptype=<?php print $static_map_type; ?>&amp;markers=color:red|<?php print $url_suffix; ?>&amp;sensor=false" />
+</div>
+<?php
+}
 if ($include_link) {
 ?>
 <p class="simple-gmap-link"><a href="http://maps.google.com/maps?q=<?php print $url_suffix; ?>&amp;hl=<?php print $langcode; ?>&amp;iwloc=<?php print ($information_bubble ? 'A': ''); ?>&amp;z=<?php print $zoom; ?>&amp;t=<?php print $map_type; ?>" target="_blank"><?php print $link_text; ?></a></p>
@@ -4,7 +4,8 @@
  *
  * Available variables:
- * - $include_map: TRUE if an embedded map should be displayed.
+ * - $include_map: TRUE if an embedded dynamic map should be displayed.
+ * - $include_static_map: TRUE if an embedded static map should be displayed.
  * - $width: Width of embedded map.
  * - $height: Height of embedded map.
